@@ -34,10 +34,7 @@ class Tempo(Object):
         """Disable the tempo."""
         await self._ipx.update_io(self.io_enabled_id, False)
 
-    async def set_time(
-        self,
-        time: int = None,
-    ) -> None:
+    async def set_time(self, time: int) -> None:
         """Update tempo time."""
         params = {"anaTime1": time}
         await self._ipx._request_api(
